summaryrefslogtreecommitdiff
path: root/tests/__init__.py
diff options
context:
space:
mode:
authorVincent Driessen <vincent@3rdcloud.com>2012-09-02 11:26:31 +0200
committerVincent Driessen <vincent@3rdcloud.com>2012-09-02 11:26:31 +0200
commit879a87d158de21fa1386e09790d41e74f48e9d54 (patch)
treee059b1316e4b7ecd22fb0199d97c9f71f33c5d64 /tests/__init__.py
parentdb82d5c1b46904d60f07a596697f9f0f33d2ed61 (diff)
downloadrq-879a87d158de21fa1386e09790d41e74f48e9d54.tar.gz
Remove logbook and replace it with logging.
This reverts commit 1ab8c19696cb6b437729401640d00fd682e96b27 and reintroduces all changes made by @dstufft. Still, it needs more patches to reeanble the default log-to-console behaviour. See #121.
Diffstat (limited to 'tests/__init__.py')
-rw-r--r--tests/__init__.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/__init__.py b/tests/__init__.py
index 09c4e4b..398d23a 100644
--- a/tests/__init__.py
+++ b/tests/__init__.py
@@ -1,6 +1,7 @@
+import logging
import unittest
+
from redis import Redis
-from logbook import NullHandler
from rq import push_connection, pop_connection
@@ -47,9 +48,8 @@ class RQTestCase(unittest.TestCase):
# Store the connection (for sanity checking)
cls.testconn = testconn
- # Shut up logbook
- cls.log_handler = NullHandler()
- cls.log_handler.push_thread()
+ # Shut up logging
+ logging.disable("ERROR")
def setUp(self):
# Flush beforewards (we like our hygiene)
@@ -66,7 +66,7 @@ class RQTestCase(unittest.TestCase):
@classmethod
def tearDownClass(cls):
- cls.log_handler.pop_thread()
+ logging.disable(logging.NOTSET)
# Pop the connection to Redis
testconn = pop_connection()